@@ -475,7 +475,7 @@ def resize_pool(client, pool_id, target_dedicated_nodes=None, target_low_priorit
 
 def replace_pool(client,
                  pool_id, json_file=None, application_package_references=None,
-                 metadata=None, target_node_communication_mode=None, start_task_command_line=None,
+                 metadata=None, start_task_command_line=None,
                  start_task_environment_settings=None, start_task_max_task_retry_count=None,
                  start_task_resource_files=None, start_task_wait_for_success=None):
     if json_file:
@@ -501,8 +501,7 @@ def replace_pool(client,
             application_package_references = []
         param = BatchPoolReplaceContent(
             application_package_references=application_package_references,
-            metadata=metadata,
-            target_node_communication_mode=target_node_communication_mode)
+            metadata=metadata)
 
         if start_task_command_line:
             param.start_task = BatchStartTask(command_line=start_task_command_line,
